@@ -723,7 +723,7 @@ class VariableClUpdateRepHost(Variable):
 
 class VariableClUpdateRepHostUrl(Variable):
     type = "list"
-    value = ['git://github.com/calculatelinux/%s.git']
+    value = ['https://github.com/calculatelinux/%s.git']
 
 
 class VariableClUpdateProfileDatavars(ReadonlyVariable):
@@ -925,7 +925,7 @@ class VariableClUpdateProfileUrl(Variable):
     profile = "cl_profile_system"
     branch = "cl_update_profile_branch"
     storage = "cl_update_profile_storage"
-    default_url = "git://github.com/calculatelinux/distros.git"
+    default_url = "https://github.com/calculatelinux/distros.git"
     profiles_shortname = 'cl_update_profile_shortname'
 
     @property
